Contributing - CUTLASS Python

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# Contributing

Thank you for your interest in contributing to the CUTLASS Python interface. Based on the type of contribution, it will fall into two categories:

1. You want to report a bug, feature request, or documentation issue

   - File an issue describing what you encountered or what you want to see changed.

   - The CUTLASS team will evaluate the issues and triage them, scheduling them for a release. If you believe the issue needs priority attention, comment on the issue to notify the team.

2. You want to implement a feature or bug-fix

   - We welcome contributions from the community. We recommend that you contribute via a pull request. If you have questions about CUTLASS, consider asking a question via the Discussions tab. Please be sure to search through both existing issues and discussions to see whether your question has already been answered.